/*
  xtopng.c - Tyler Montbriand, 2004.

  Based on zlib license, see http://www.gzip.org/zlib/zlib_license.html

  This software is provided 'as-is', without any express or implied
  warranty.  In no event will the authors be held liable for any damages
  arising from the use of this software.

  Permission is granted to anyone to use this software for any purpose,
  including commercial applications, and to alter it and redistribute it
  freely, subject to the following restrictions:

  1. The origin of this software must not be misrepresented; you must not
     claim that you wrote the original software. If you use this software
     in a product, an acknowledgment in the product documentation would be
     appreciated but is not required.
  2. Altered source versions must be plainly marked as such, and must not be
     misrepresented as being the original software.
  3. This notice may not be removed or altered from any source distribution.

  "Tyler Montbriand", tsm@accesscomm.ca
 */

#include <unistd.h>
#include <SDL/SDL_image.h>
#include <stdio.h>
#include <string.h>
#include "IMG_savepng.h"

int main(int argc, char *argv[])
{
  int compression=IMG_COMPRESS_DEFAULT,n;
  int shouldremove=0;

  if(argc<2)
  {
    fprintf(stderr,"Syntax: xtopng [flag1] [flag2] file1 [file2] [...]\n"
                   "  -[0-9]:  Compression level.  0-off, 9-max.\n"
                   "  -r:      Remove input files.  Off by default.\n\n");
    return(1);
  }

  n=1;
  while(argv[n][0]=='-')
  {
    switch(argv[n][1])
    {
    case '0':    case '1':    case '2':    case '3':    case '4':
    case '5':    case '6':    case '7':    case '8':    case '9':
      compression=argv[n][1]-'0';
      break;

    case 'r':
    case 'R':
      shouldremove=1;
      break;

    default:
      fprintf(stderr,"Invalid option %s\n",argv[n]);
      return(1);
      break;
    }
    n++;
    if(n==argc) break;
  }

  if(SDL_Init(0)<0)
  {
    fprintf(stderr,"Couldn't init SDL: %s\n",SDL_GetError());
    return(1);
  }

  for(; n<argc; n++)
  {
    char nameout[512];
    strcpy(nameout,argv[n]);

    {
      char *ext=strrchr(nameout,'.');
      if(strlen(ext)==4)
        strcpy(ext,".png");
      else
        strcat(ext,".png");
    }

    SDL_Surface *s=IMG_Load(argv[n]);
    if(s==NULL)
    {
      fprintf(stderr,"Couldn't load %s: %s\n",argv[n],SDL_GetError());
      continue;
    }

    fprintf(stderr,"%s...",nameout);
    if(IMG_SavePNG(nameout,s,compression)<0)
      fprintf(stderr,"Error saving file:%s\n",SDL_GetError());
    else
      fprintf(stderr,"Saved file.\n");

    SDL_FreeSurface(s);

    if(shouldremove)
    {
      if(access(argv[n],W_OK))
        fprintf(stderr,"%s is read-only, will not remove\n",argv[n]);
      else if(remove(argv[n])<0)
          fprintf(stderr,"Input file %s cannot be removed\n",argv[n]);
    }
  }

  SDL_Quit();
  return(0);
}
